@@ -7,4 +7,4 @@ from easyconfig.models import AppBaseModel, AppBaseSettings, AppConfigMixin, Bas
 
 # isort: split
 
-from easyconfig.config_objs import create_app_config
+from easyconfig.create_app_config import create_app_config
