@@ -2,5 +2,5 @@ from .subscription import ConfigObjSubscription, SubscriptionParent
 
 # isort: split
 
-from .app_config import AppConfig, create_app_config
+from .app_config import AppConfig
 from .object_config import ConfigObj, HINT_CONFIG_OBJ, HINT_CONFIG_OBJ_TYPE
